pub struct ServoDangerousStyleDocument<'dom> {
document: LayoutDom<'dom, Document>,
}Expand description
A wrapper around documents that ensures layout can only ever access safe properties.
TODO: This should become a trait like LayoutNode.
Fields
document: LayoutDom<'dom, Document>The wrapped private DOM Document
Implementations
Sourceimpl<'dom> ServoDangerousStyleDocument<'dom>
impl<'dom> ServoDangerousStyleDocument<'dom>
Sourcepub fn root_element(&self) -> Option<ServoLayoutElement<'dom>>
pub fn root_element(&self) -> Option<ServoLayoutElement<'dom>>
Get the root node for this ServoDangerousStyleDocument.
Get the shared style lock for styling with Stylo for this ServoDangerousStyleDocument.
Sourcepub fn flush_shadow_root_stylesheets_if_necessary(
&self,
stylist: &mut Stylist,
guard: &StyleSharedRwLockReadGuard<'_>,
)
pub fn flush_shadow_root_stylesheets_if_necessary( &self, stylist: &mut Stylist, guard: &StyleSharedRwLockReadGuard<'_>, )
Flush the the stylesheets of all descendant shadow roots.